using System;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Net;
using System.IO;
using System.Text;
using System.Text.RegularExpressions;

public partial class AsyncronousCall : System.Web.UI.Page
{
    protected void Page_Load(object sender, EventArgs e)
    {
        //asssign the Begin and End Operation Callback methods.
        AddOnPreRenderCompleteAsync(
            new BeginEventHandler(BeginAsyncOperation),
            new EndEventHandler(EndAsyncOperation));
    }

    private WebRequest _request;
    /// <summary>
    /// The begin Operation is the first method called in an async transaction,
    /// All data Custom AsyncResults and data initialization is done here.
    /// 
    /// in this example we call an external website (www.amazon.co.uk) and 
    /// show the Resultin a literal control.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    /// <param name="cb">EndAsyncOperation Callback</param>
    /// <param name="state"></param>
    /// <returns></returns>
    public IAsyncResult BeginAsyncOperation(object sender, EventArgs e, AsyncCallback cb, object state)
    {
        _request = WebRequest.Create("http://www.amazon.co.uk");
        return _request.BeginGetResponse(cb, state);
    }

    /// <summary>
    /// The method is the final method called by the async transaction,As this 
    /// method is called before the page render method all custom rendering 
    /// and data preparation is done here before passing it back
    /// to the client. 
    /// </summary>
    /// <param name="ar">This AsyncResult Object is the object created in the 
    /// BeginAsyncoperation and contain the state information, if a custom 
    /// AsyncResult is created it will be passed in using this parameter.</param>
    public void EndAsyncOperation(IAsyncResult ar)
    {
        try
        {
            using (WebResponse response = _request.EndGetResponse(ar))
            {
                using (StreamReader reader = new StreamReader(response.GetResponseStream()))
                {
                    Literal1.Text = reader.ReadToEnd();
                }
            }
         }
        catch (HttpException ex)
        {
            Literal1.Text = ex.Message;
        }
    }

}
 
